Arguments
x
A character vector, as the input protein sequence.
propmat
The matrix containing the descriptor set for the amino acids,
which could be chosen from
AAMOE2D, AAMOE3D, AACPSA,
AADescAll, AA2DACOR, AA3DMoRSE,
AAACF, AABu
index
Integer vector or character vector. Specify which molecular descriptors
to select from one of these deseriptor sets by specify the
numerical or character index of the molecular descriptors in the descriptor set.
Default is NULL, means selecti
pc
Integer. The maximum dimension of the space which the data
are to be represented in.
Must be no greater than the number of AA properties provided.
lag
The lag parameter. Must be less than the amino acids.
scale
Logical. Should we auto-scale the property matrix
(propmat) before doing MDS? Default is TRUE.
silent
Logical. Whether we print the standard deviation,
proportion of variance and the cumulative proportion of
the selected principal components or not.
Default is TRUE.