readFASTA(file = system.file("protseq/P00750.fasta", package = "protr"),
legacy.mode = TRUE, seqonly = FALSE)TRUE, lines starting with a semicolon ';'
are ignored. Default value is TRUE.TRUE, only sequences as returned without
attempt to modify them or to get their names and
annotations (execution time is divided approximately
by a factor 3). Default value isThe three returned argument are just different forms of the same output. If one is interested in a Mahalanobis metric over the original data space, the first argument is all she/he needs. If a transformation into another space (where one can use the Euclidean metric) is preferred, the second returned argument is sufficient. Using A and B is equivalent in the following sense.
getUniProt for retrieving protein sequences
from uniprot.orgP00750 = readFASTA(system.file('protseq/P00750.fasta', package = 'protr'))Run the code above in your browser using DataLab